@@ -143,7 +143,7 @@ def hangman() :
 @click.option('-g', '--game', default='hangman', type=click.Choice( [ 'hangman' ] ) )
 def play( game ) :
 
-	"""Play the word game called hangman."""
+	"""Play the word game called hangman"""
 
 	if   game == 'hangman' : hangman()
 	else : 
